#
# spec file for package libhandy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_major 1
%define shlib %{name}-%{so_major}-0
%define typelib typelib-1_0-Handy-%{so_major}_0
%define with_glade 1

Name:           libhandy
Version:        1.8.3
Release:        1.3
Summary:        A GTK+ library to develop UI for mobile devices
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://gitlab.gnome.org/GNOME/libhandy
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  meson >= 0.49.0
BuildRequires:  pkgconfig
BuildRequires:  vala
%if 0%{?with_glade}
BuildRequires:  pkgconfig(gladeui-2.0)
%endif
BuildRequires:  pkgconfig(gi-docgen) >= 2021.1
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.1

%description
libhandy is a library to help with developing UI for mobile devices
using GTK+/GNOME.

%package -n %{shlib}
Summary:        A GTK+ library to develop UI for mobile devices
Group:          System/Libraries
Provides:       %{name} = %{version}

%description -n %{shlib}
This package provides the shared library for libhandy, a library to
help with developing mobile UI using GTK+/GNOME.

%package devel
Summary:        Source and header files for %{name}
Group:          Development/Libraries/GNOME
Requires:       %{shlib} = %{version}
Requires:       %{typelib} = %{version}

%description devel
This package provides the source and header files for writing
software using %{name}, a library to help with developing mobile UI
using GTK+/GNOME.

%package -n %{typelib}
Summary:        Introspection bindings for libhandy
Group:          System/Libraries

%description -n %{typelib}
This package provides the GObject Introspection bindings for
%{name}, a library to help with developing mobile UI using
GTK+/GNOME.

%package -n glade-catalog-libhandy
Summary:        Glade catalog for libhandy
Group:          Development/Tools/GUI Builders
Requires:       glade
Supplements:    (glade and %{name}-devel)

%description -n glade-catalog-libhandy
libhandy is a library to help with developing UI for mobile devices
using GTK+/GNOME.

This package provides a catalog for libhandy, to allow the use
libhandy widgets in Glade.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D profiling=false \
	-D introspection=enabled \
	-D vapi=true \
	-D gtk_doc=true \
	-D tests=false \
	-D examples=false \
	-D glade_catalog=%{?with_glade:enabled}%{?!with_glade:disabled} \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name}

%ldconfig_scriptlets -n %{shlib}

%files -n %{shlib}
%{_libdir}/libhandy-*.so.*

%files devel
%license COPYING
%doc AUTHORS README.md
%{_includedir}/libhandy-%{so_major}/
%{_libdir}/libhandy-*.so
%{_datadir}/gir-1.0/*.gir
%{_libdir}/pkgconfig/libhandy-%{so_major}.pc
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libhandy-*
%{_datadir}/doc/libhandy-%{so_major}/

%files -n %{typelib}
%{_libdir}/girepository-1.0/*.typelib

%if 0%{?with_glade}
%files -n glade-catalog-libhandy
%{_libdir}/glade/modules/*.so
%{_datadir}/glade/catalogs/*.xml
%endif

%files lang -f %{name}.lang

%changelog
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.8.3:
  + HdyStyleManager:
  - Support contrast setting in the settings portal.
  - Remove an extra unref.
  + Updated translations.
* Sun Mar  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.2:
  + Demo:
  - Correctly use GtkSwitch
  - Fix a GLib deprecation
  + Docs: Fix dependency names
  + HdyTabView:
  - Fix set_menu_model() input check
  - Fix a typo in docs
  + HdySwipeable: Fix get_swipe_area() fallback
  + Memory leak fixes
  + Updated translations.
* Wed Feb  1 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.1:
  + Fix double click handling for HdyWindowHandle and HdyHeaderBar.
  + Updated translations.
* Thu Sep 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.0:
  + Updated translations.
* Fri Aug  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.7.90:
  + Remove unnecessary cast in HdyPreferencesGroup.
  + Updated translations.
* Sun Jul 17 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.7.0:
  + HdyDeck: Remove a non-existent property mention.
  + HdyStyleManager:
  - Correctly reset the theme if we're not overriding it. Fixes
    switching away from HighContrast.
  - Fix a typo in docs.
  - Remove a leftover debug message.
  + Add environment variables to control styles from Builder.
* Sun Jul 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.3:
  + Remove a non-existent property mention from HdyDeck docs.
  + Remove a leftover debug message from HdySettings.
  + Updated translations.
* Sun Apr 24 2022 Dirk Müller <dmueller@suse.com>
- Update to version 1.6.2:
  + Fix license in docs.
  + Fix a Meson error when using as a subproject.
  + Fix a typo in HdyStyleManager docs.
  + Updated translations.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.1:
  + HdyStyleManager: Correctly reset the theme if we're not
    overriding it. Fixes switching away from HighContrast.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.0:
  + Fix introspection-related build warnings.
  + AdwStyleManager: Make color-scheme work with GTK themes ending
    in -dark.
  + Updated translations.
* Mon Mar  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.5.91:
  + HdyAvatar: Fix invalid UTF-8 handling.
  + HdyStyleManager: Don't disable non-CSS animations during style
    changes.
  + Fix carousel indicator sizing.
* Fri Feb 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.5.90:
  + Documentation:
  - Port to gi-docgen
  - Use "Since: 1.0" for pre-1.0 symbols
  - Various cleanups and consistency updates
  + Demo:
  - Fix keyboard navigation
  - Don't make rows containing buttons activatable
  - Set minimum width on the view switcher window
  + HdyCarousel: Properly remove mouse wheel timer
  + HdyClamp: Fix measuring
  + HdyKeypad: Fix keyboard navigation
  + HdyStyleManager: Properly reset animations after style changes
  + HdySwipeTracker: Fix a runtime warning
  + HdyTabView: Propagate Alt+[0-9] when trying to switch to the
    selected tab
  + HdyViewSwitcher: Properly center button labels
  + Build and CI cleanups
  + Remove unused distro packaging
  + Updated translations.
- Replace gtk-doc with pkgconfig(gi-docgen) BuildRequires following
  upstreams port.
* Fri Nov 12 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.5.0:
  + Introduce HdyStyleManager for managing color schemes
    (light/dark) and high contrast mode.
  - Support the cross-platform color scheme preference in the
    settings portal.
  + HdyPreferencesPage: Remove adaptive margins to fix default
    window sizes.
  + HdyTabBar: Handle middle click on button release rather than
    press.
  + Various memory leak fixes.
  + Updated translations.
- Use ldconfig_scriptlets macro for post(un) handling.
* Thu Nov  4 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Stop passing the no longer user nor recognized option
  static=false to meson.
* Mon Sep  6 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.4.0:
  + Updated translations.
* Thu Sep  2 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.3.90:
  + HdyAvatar: Fix giving it the .image style class when needed.
  + HdyCarousel:
  - Add the allow-scroll-wheel property.
  - Fix the child size allocation.
  + HdyPreferencesGroup: Add the use-markup property.
  + Deprecate HdySwipeGroup and HdyTitleBar.
  + Fix translations by setting the translation domain in UI files.
  + Updated translations.
- Move to regular tarballs: drop _service file.
* Mon Jun 21 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.2.3:
  + HdySqueezer: Fix a size allocation issue.
  + HdyTabBar: Fix a leak.
  + HdyAvatar: Fix getting the pixbuf from the avatar.
  + HdyClamp: Fix using "size" and not "width" in the
    documentation.
  + HdyDeck and HdyLeaflet: Null check a child before using it when
    looking for a swipeable one.
  + Specify the translation domain in UI files.
  + Remove some unused code.
  + Updated translations.
* Fri Apr 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.2.2:
  + HdySqueezer:
  - Make the vertical orientation work.
  - Fix usage of xalign with RTL.
  + HdyComboRow: Focus selected row when opening the popover.
  + HdyAvatar: Fix a crash when loading icons.
  + Demo: Fix RTL sidebar icons.
* Sat Apr 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.2.1:
  + hdydeck and hdyleaflet:
  - Skip the unfolded allocation phase if there are no visible
    children, fixing a crash.
  - Fix the reverse child order.
  + hdyheaderbar: stop force centering an expanded title when
    loose.
  + hdyflap: fix shadow glitches on flap child resizes.
  + hdypreferenceswindow:
  - give the window the .preferences style class.
  - make the search results page's margins adaptive.
  + demo: fix a memory leak in the view switcher demo.
  + meson: avoid trailing slashes in directories if package_subdir
    is empty.
* Wed Mar 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.2.0:
  + Fix deprecation warnings when including handy.h.
  + Fix warnings with -Wmissing-field-initializers.
  + Fix warnings with --buildtype=optimized.
  + Fix a crash when subclassing HdyPreferencesGroup.
  + Fix a build reproducibility issue by using basenames rather
    than full paths in generated sources.
  + Updated translations.
* Mon Feb 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.1.90:
  + Add HdyFlap, allowing to have adaptive tab bars and header
    bars.
  + Add HdyTabBar and HdyTabView, offering a modern tab bar.
  + Add HdyStatusPage, a convenient widget for welcome pages, empty
    state pages, or error pages.
  + HdyAvatar:
  - Add the loadable  -icon property to allow setting a
    GLoadableIcon as the avatar picture.
  - Deprecate hdy_avatar_set_image_load_func() in favor of the
    loadable  -icon property.
  - Add hdy_avatar_draw_to_pixbuf() and
    hdy_avatar_draw_to_pixbuf_async() to export the avatar as a
    GdkPixbuf.
  - Take CSS sizing properties into account.
  + HdyPreferencesWindow:
  - Use HdyStatusPage as the empty search result page to
    standardize the page's look.
  + HdyPreferencesPage:
  - Propagate the natural height of the scrolled content.
  - Make the scrolled window automatically follow the focus.
  - Implement the margins via CSS so applications can override
    them.
  - Make the margins adapt to the available width.
  + HdyPreferencesGroup:
  - Allow navigating out of the listbox.
  - Wrap labels on words or characters, preventing long words
    from breaking the UI.
  - Take CSS sizing properties into account.
  - Implement the margins via CSS so applications can override
    them.
  - Refine the spacing.
  - Protect against gtk_widget_show_all().
  - Fix a leak when destroying the widget.
  - Add accessibility relationships for the title.
  + HdyClamp:
  - Fix measuring the widget even without a child.
  - Take CSS sizing properties into account.
  + HdyActionRow:
  - Add the title  -lines and subtitle  -lines properties to set
    the number of lines the title and subtitle should be limited
    to, 0 giving an unlimited lines number.
  - Wrap labels on words or characters, preventing long words
    from breaking the UI.
  - Document that hdy_action_row_get_icon_name() doesn't transfer
    string ownership.
  - Add accessibility relationships for the title.
  + HdyComboRow:
  - Fix showing the checkmark on the right item.
  - Use object  -select  -symbolic instead of emblem  -ok
  - symbolic as the selected item checkmark icon, as it is more
    semantically correct.
  + HdySwipeTracker:
  - Add the allow  -long  -swipes property to allow swiping more
    than one snap point at a time.
  - Calculate the velocity with a scroll history to gain
    precision.
  - Fix coordinate transformation for scrolling.
  - Don't leak the current event.
  + HdyCarousel:
  - Add the allow  -long  -swipes property to allow swiping more
    than one child at a time.
  - Fix a size invalidation issue.
  + HdyDeck:
  - Add the hdy_deck_prepend(), hdy_deck_insert_child_after(),
    and hdy_deck_reorder_child_after() methods.
  - Increase the edge swipe area from 16px to 32px.
  - Fix the ntural size calculation.
  + HdyLeaflet:
  - Add the hdy_leaflet_prepend(),
    hdy_leaflet_insert_child_after(), and
    hdy_leaflet_reorder_child_after() methods.
  - Increase the edge swipe area from 16px to 32px.
  + HdyKeypad:
  - Beep when typing invalid characters.
  - Allow pasting and erasing text in the entry.
  - Fix allowing + when symbols are visible instead of hidden.
  + Updated translations.
* Fri Dec 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.3:
  + Fix build warnings with newer GCC.
  + HdyActionRow: Clarify hdy_action_row_get_icon_name()
    documentation.
  + HdyCarousel: Fix drawing cache invalidation on resize.
  + HdyComboRow: Use the right checkmark icon.
  + HdyLeaflet and HdyDeck: Increase the edge swipe area size.
  + HdyKeypad: Fix typing the '+' symbol.
  + HdyPreferencesGroup:
  - Fix a memory leak when destroying the widget.
  - Don't show empty title and description when using
    gtk_widget_show_all().
  + HdySwipeTracker:
  - Correctly transform widget coordinates for touchpad swipes.
  - Fix a memory leak.
* Thu Nov 12 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.0.2:
  + Fix gtk-doc install path.
  + HdyCarousel: Fix pages not being drawn until scrolled on X11.
  + HdyComboRow: Fix test failures on x86.
  + HdyLeaflet and HdyDeck: Fix transition shadow on HiDPI.
  + HdySwipeTracker:
  - Fix touchpad swipes not working after pressing a GtkButton.
  - Fix swipes in nested swipeable widgets when started from a
    GtkButton.
  + HdyViewSwitcherTitle: Mark title and subtitle properties as
    translatable for Glade.
  + Updated translations.
* Mon Nov  2 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.0.1:
  + Fix build with Glade 3.37.
  + Fix a Meson version warning.
  + HdyAvatar:
  - Minimize the amount of redundant load_image() calls.
  - Center non-square custom images.
  - Add .image style class to avatars with custom images.
  - Allow css border and shadow on avatars with custom images so
    elementary can style it.
  + HdyCarousel:
  - Fix drawing cache.
  - Fix crash when scrolling over empty carousel.
  + HdyComboRow:
  - Fix popover hiding animation when clicking a row.
  - Always reserve space for checkmarks.
  + HdyHeaderGroup: Fix a warning on nesting HdyHeaderGroups.
  + HdyKeypad: Fix input of the #, @ and + characters.
  + HdyLeaflet and HdyDeck: Fix minimum size when
    'interpolate-size' property is TRUE.
  + HdyPreferencesWindow: Fix searching rows that have mnemonics.
  + HdySwipeTracker:
  - Fix swipes not working if started from GtkButton.
  - Increase drag threshold for touchscreens.
  - Avoid a jump when starting a drag.
  + HdyViewSwitcher: Fix sizing with invisible pages.
  + Updated translations.
- Re-enable glade catalog build: define with_glade 1: upstream
  fixed the build issue.
* Wed Sep  9 2020 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 1.0.0: No change, only version bump.
* Wed Sep  9 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Provide %%{name} = %%{version} in shlib package in order to make
  - lang package installable: needed as there is no main package.
* Sat Sep  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.91.0:
  + Update HdyComboRow's state when its model is changed.
  + Fix padding application in HdyHeaderBar.
  + HdyPreferencesWindow:
  - Translate the keyval properly to ensure keyboard shortcuts
    work with all keymaps.
  - Allow closing the window or subpages with the Esc key.
  + HdyWindow and HdyApplicationWindow:
  - Fix a memory leak when destroying the widget.
  - Get the state from the correct style context to avoid a
    constant redraw after changing the text direction and before
    the window is focused.
  - Don't force a 0px border-radius on the window to give more
    freedom to elementary.
  + Updated translations.
- Disable glade catalogs for the time being: not compatible with
  glade 3.37.
* Fri Aug 28 2020 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 0.90.0:
  + Stop requiring the HANDY_USE_UNSTABLE_API guard.
  + Stop transforming close buttons into back buttons for dialogs
    on the desktop.
  + Give some nice default and minimum sizes to
    HdyPreferencesWindow.
  + HdyCarousel:
  - Add HdyCarouselIndicatorDots and HdyCarouselIndicatorLines.
  - Drop the indicator-style, indicator-spacing, and
    center-content properties.
  + Revamp the colors of HdyAvatar and augment its colors number to
    14.
  + Set the default column and row spacing of HdyKeypad to 6
    pixels.
  + Don't present an arrow and a popover in HdyComboRow when its
    model has less than 2 items.
  + Support CSS sizing properties for HdySqueezer and
    HdyViewSwitcher.
  + Drop the icon-size properties of HdyViewSwitcher,
    HdyViewSwitcherTitle  and HdyViewSwitcherBar.
  + Give some horizontal margins to the view switcher of
    HdyViewSwitcherTitle via CSS.
  + Add all files back to tarballs except the debian directory.
- Remove libhandy-adapt-glade-3-36.patch: Fixed upstream.
- Update shlib suffix to 1_0 to reflect the API update from version
  0.0.13.
- Use new URL and git repository from GNOME's GitLab.
* Tue Aug 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Remove meson_build libhandy-doc call: it was a NOP and fails with
  meson 0.55.
* Fri May  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add libhandy-adapt-glade-3-36.patch: Fix build with new glade
  3.36.0.
* Fri Jan 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.0.13:
  + Various build and bug fixes.
* Thu Sep 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.0.11:
  + Various build and bug fixes.
- Switch to source service.
* Thu Jun 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.0.10:
  + Various build and bug fixes.
* Thu Mar  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.0.9:
  + Various build and bug fixes.
- Drop libhandy-fix-translations.patch: Fixed upstream.
* Fri Mar  1 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add libhandy-fix-translations.patch: Fix broken translations in
  apps using libhandy.
* Sat Feb 16 2019 bjorn.lie@gmail.com
- Update to version 0.0.8:
  + Various build and bug fixes, including a few memory leak fixes.
* Fri Jan 18 2019 bjorn.lie@gmail.com
- Update to version 0.0.7:
  + Various build and bug fixes.
  + Add introspection and the Glade catalog features.
  + Allow building as static lib.
  + Update documentation.
- Pass explicit options to meson, ensure we build the features we
  want and do not want.
* Mon Dec 24 2018 bjorn.lie@gmail.com
- Update to version 0.0.6:
  + Various buildfixes.
  + Reproduciable builds should now be possible.
  + Header bar cleanup.
- Changes from version 0.0.5:
  + meson: Properly depend on the generated headers.
  + Remove styles, depend on gtk to provide them.
- Drop libhandy-generated-header-dependency.patch: Fixed upstream.
* Fri Nov  9 2018 Jan Engelhardt <jengelh@inai.de>
- Update summary.
* Mon Nov  5 2018 badshah400@gmail.com
- Add libhandy-generated-header-dependency.patch: Fix dependency
  problems with headers generated by meson; fixes build for 32
  bit; patch taken from upstream git
  (https://source.puri.sm/Librem5/libhandy/issues/60).
- Enable parallel builds for i586.
* Wed Oct 31 2018 badshah400@gmail.com
- Use -j1 when building for i586, as parallel builds fail
  (https://source.puri.sm/Librem5/libhandy/issues/60).
* Wed Oct 31 2018 badshah400@gmail.com
- Initial package.
